/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_mean\":{\"type\":\"array\",\"description\":\"Mean range "
    "[m]\",\"items\":{\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"array\",\"desc"
    "ription\":\"Mean amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"angle\":{\"ty"
    "pe\":\"array\",\"description\":\"Angle [deg]\",\"items\":{\"type\":\"number\"}}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"req"
    "uired\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"description\":\"Angular "
    "notch filter parameters for window glass echoes\",\"title\":\"Angular "
    "Notch Filter\"}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.12"
    "0913,2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospher"
    "ic attenuation "
    "[1/km]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group velocity "
    "of laser beam "
    "[m/s]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) [m]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure"
    " along measurment path [mbar]\"}},\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"type\":\"object\",\"required\":[\"temperature\",\"pressure\",\"r"
    "el_humidity\",\"pressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"wave"
    "length\"],\"description\":\"Atmospheric parameters\",\"title\":\"Atmospheric "
    "Parameters\"}"
    ,
    /* example: */
    "{\"attenuation\":0.028125,\"rel_humidity\":63,\"group_velocity\":299711000.0"
    ",\"temperature\":7,\"pressure_sl\":970,\"wavelength\":1550,\"amsl\":0,\"pressur"
    "e\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"beam_divergence\":{\"minimum\":0,\"exclusiveMinimum\":false"
    ",\"type\":\"number\",\"description\":\"Beam divergence in far field [rad]\"},\""
    "beam_exit_diameter\":{\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"numb"
    "er\",\"description\":\"Beam width at exit aperture [m]\"}},\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"beam_"
    "exit_diameter\",\"beam_divergence\"],\"description\":\"Laser beam geometry "
    "details\",\"title\":\"Beam Geometry\"}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"types\":{\"type\":\"array\",\"uniqueItems\":true,\"items\":{\"ty"
    "pe\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/de"
    "finitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\""
    "#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref"
    "\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round_corner_cube_pri"
    "sm\"}]}}},\"definitions\":{\"chevron\":{\"allOf\":[{\"$ref\":\"#/definitions/com"
    "mon\"},{\"properties\":{\"outside_edge_length\":{\"minimum\":0,\"exclusiveMini"
    "mum\":true,\"type\":\"number\",\"description\":\"length of the two outer edges"
    " in meters\"},\"thickness\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\""
    "number\",\"description\":\"thickness in meters\"},\"shape\":{\"enum\":[\"chevron"
    "\"],\"type\":\"string\",\"description\":\"shape identifier\"}},\"required\":[\"sha"
    "pe\",\"outside_edge_length\",\"thickness\"],\"type\":\"object\",\"description\":\""
    "chevron specific properties\"}],\"type\":\"object\",\"description\":\"chevron\""
    "},\"common\":{\"properties\":{\"surface_type\":{\"enum\":[\"retro_reflective_fo"
    "il\",\"diffuse\"],\"type\":\"string\",\"description\":\"surface material "
    "type\"},\"description\":{\"type\":\"string\",\"description\":\"string describing"
    " the "
    "object\"},\"name\":{\"minLength\":3,\"type\":\"string\",\"description\":\"unique "
    "type identifier\"},\"shape\":{\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chev"
    "ron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"],\"t"
    "ype\":\"string\",\"description\":\"shape identifier\"}},\"required\":[\"name\",\"s"
    "hape\"],\"type\":\"object\",\"description\":\"common object properties\"},\"sphe"
    "re\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"diameter"
    "\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"description\":\""
    "diameter in meters\"},\"shape\":{\"enum\":[\"sphere\"],\"type\":\"string\",\"descr"
    "iption\":\"shape identifier\"}},\"required\":[\"shape\",\"diameter\"],\"type\":\"o"
    "bject\",\"description\":\"sphere specific properties\"}],\"type\":\"object\",\"d"
    "escription\":\"sphere\"},\"rectangle\":{\"allOf\":[{\"$ref\":\"#/definitions/com"
    "mon\"},{\"properties\":{\"width\":{\"minimum\":0,\"exclusiveMinimum\":true,\"typ"
    "e\":\"number\",\"description\":\"width in meters\"},\"length\":{\"minimum\":0,\"ex"
    "clusiveMinimum\":true,\"type\":\"number\",\"description\":\"length in meters\"}"
    ",\"shape\":{\"enum\":[\"rectangle\"],\"type\":\"string\"}},\"required\":[\"shape\",\""
    "length\",\"width\"],\"type\":\"object\",\"description\":\"rectangle specific pro"
    "perties\"}],\"type\":\"object\",\"description\":\"rectangle\"},\"circular_disk\":"
    "{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\"offset\":{\"ty"
    "pe\":\"number\",\"description\":\"offset in meters, e.g. reflector constant "
    "(optional)\"},\"diameter\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"n"
    "umber\",\"description\":\"diameter in meters\"},\"shape\":{\"enum\":[\"circular_"
    "disk\"],\"type\":\"string\",\"description\":\"shape identifier\"}},\"required\":["
    "\"shape\",\"diameter\"],\"type\":\"object\",\"description\":\"circular disk "
    "specific properties\"}],\"type\":\"object\",\"description\":\"circular disk\"},"
    "\"round_corner_cube_prism\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\""
    "properties\":{\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"minimum\":0,\""
    "exclusiveMinimum\":true,\"type\":\"number\",\"description\":\"diameter in mete"
    "rs\"},\"shape\":{\"enum\":[\"round_corner_cube_prism\"],\"type\":\"string\",\"desc"
    "ription\":\"shape identifier\"}},\"required\":[\"shape\",\"diameter\"],\"type\":\""
    "object\",\"description\":\"round corner cube prism specific "
    "properties\"}],\"type\":\"object\",\"description\":\"round corner cube prism\"}"
    ",\"cylinder\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"properties\":{\""
    "height\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"descript"
    "ion\":\"height in meters\"},\"diameter\":{\"minimum\":0,\"exclusiveMinimum\":tr"
    "ue,\"type\":\"number\",\"description\":\"diameter in meters\"},\"shape\":{\"enum\""
    ":[\"cylinder\"],\"type\":\"string\",\"description\":\"shape identifier\"}},\"requ"
    "ired\":[\"shape\",\"diameter\",\"height\"],\"type\":\"object\",\"description\":\"cyl"
    "inder specific properties\"}],\"type\":\"object\",\"description\":\"cylinder\"}"
    ",\"checkerboard2x2\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"propert"
    "ies\":{\"square_length\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"num"
    "ber\",\"description\":\"length of a square of the checkerboard in meters\"}"
    ",\"shape\":{\"enum\":[\"checkerboard2x2\"],\"type\":\"string\",\"description\":\"sh"
    "ape identifier\"}},\"required\":[\"shape\",\"square_length\"],\"type\":\"object\""
    ",\"description\":\"checkerboard specific "
    "properties\"}],\"type\":\"object\",\"description\":\"checkerboard 2 by 2\"}},\"t"
    "ype\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"req"
    "uired\":[\"types\"],\"description\":\"List of control object type "
    "definitions\",\"title\":\"Control Object Catalog\"}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"],\"types\":[{\"width\":0.3,"
    "\"length\":0.6,\"description\":\"Rectangle (60cm x 30cm)\",\"name\":\"Rectangle"
    " 60x30\",\"shape\":\"rectangle\"},{\"width\":0.4,\"length\":0.8,\"description\":\""
    "Rectangle (80cm x 40cm)\",\"name\":\"Rectangle 80x40\",\"shape\":\"rectangle\"}"
    ",{\"square_length\":0.3,\"description\":\"Checkerboard (square length: "
    "30cm)\",\"name\":\"Checkerboard2x2 30\",\"shape\":\"checkerboard2x2\"},{\"square"
    "_length\":0.5,\"description\":\"Checkerboard (square length: "
    "50cm)\",\"name\":\"Checkerboard2x2 50\",\"shape\":\"checkerboard2x2\"},{\"outsid"
    "e_edge_length\":0.6096,\"thickness\":0.1016,\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"name\":\"Chevron 24''/4''\",\"shape\":\"chevron\"},{\"diamet"
    "er\":0.5,\"surface_type\":\"diffuse\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\",\"name\":\"Circular Disk "
    "50\",\"shape\":\"circular_disk\"},{\"diameter\":0.05,\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflect"
    "ive_foil\",\"description\":\"flat circular reflector from retro-reflective"
    " foil\",\"offset\":0.0},{\"diameter\":0.1,\"name\":\"RIEGL flat reflector 100 "
    "mm\",\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflective_foil\",\"de"
    "scription\":\"flat circular reflector from retro-reflective "
    "foil\",\"offset\":0.0},{\"diameter\":0.15,\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"shape\":\"circular_disk\",\"surface_type\":\"retro_reflective_foil\",\"de"
    "scription\":\"flat circular reflector from retro-reflective "
    "foil\",\"offset\":0.0},{\"diameter\":0.05,\"name\":\"RIEGL cylindrical "
    "reflector 50 "
    "mm\",\"height\":0.05,\"shape\":\"cylinder\",\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\"},{\"diameter\":0.1,\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"height\":0.1,\"shape\":\"cylinder\",\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\"},{\"diameter\":0.2,\"description\":\"Sphere (diameter: 200 "
    "mm)\",\"name\":\"Sphere 200 mm\",\"shape\":\"sphere\"},{\"diameter\":0.05,\"offset"
    "\":0.0,\"description\":\"round corner cube prism\",\"name\":\"Corner Cube "
    "Prism 50 mm\",\"shape\":\"round_corner_cube_prism\"}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"reference_file\":{\"properties\":{\"file_uuid\":{\"type\":\"st"
    "ring\",\"description\":\"Control object file's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring file\"}},\"required\":[\"file_uu"
    "id\",\"file_path\"],\"type\":\"object\",\"description\":\"Reference to a control"
    " object file\"}},\"type\":\"object\",\"description\":\"Details about the "
    "control object reference file\",\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"title\":\"Control Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"detection_probability\":{\"type\":\"array\",\"description\":\""
    "Detection probability [0..1]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{"
    "\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\""
    "}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"required\":[\"amplitude\",\"detection_probability\"],\"description\":\"Dete"
    "ction probability as a function of amplitude\",\"title\":\"Detection "
    "Probability\"}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"channel_number\":{\"minimum\":0,\"exclusiveMinimum\":false,\"typ"
    "e\":\"integer\",\"description\":\"Laser channel number (not defined or 0: "
    "single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel devices)\"}"
    "},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\","
    "\"required\":[\"device_type\",\"serial_number\"],\"description\":\"Details "
    "about the device used to acquire the point cloud\",\"title\":\"Device "
    "Information\"}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\",\"device_type\":\"V"
    "Z-400i\",\"device_build\":\"\",\"channel_number\":0,\"channel_text\":\"\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"primary\":{\"properties\":{\"content\":{\"type\":\"array\",\"des"
    "cription\":\"Internal calibration values\",\"items\":{\"type\":\"number\"}},\"ID"
    "\":{\"maxItems\":2,\"minItems\":2,\"type\":\"array\",\"description\":\"Structure i"
    "dentifier\",\"items\":{\"type\":\"integer\"}}},\"required\":[\"ID\",\"content\"],\"t"
    "ype\":\"object\",\"description\":\"Primary device geometry structure (mandat"
    "ory)\"},\"secondary\":{\"properties\":{\"content\":{\"type\":\"array\",\"descripti"
    "on\":\"Internal calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"ma"
    "xItems\":2,\"minItems\":2,\"type\":\"array\",\"description\":\"Structure identif"
    "ier\",\"items\":{\"type\":\"integer\"}}},\"required\":[\"ID\",\"content\"],\"type\":\""
    "object\",\"description\":\"Additional device geometry structure (optional)"
    "\"},\"amu\":{\"properties\":{\"frameCC\":{\"minimum\":0,\"exclusiveMinimum\":fals"
    "e,\"type\":\"number\",\"description\":\"Frame Circle Count (number of LSBs "
    "per full rotation about frame axis)\"},\"lineCC\":{\"minimum\":0,\"exclusive"
    "Minimum\":false,\"type\":\"number\",\"description\":\"Line Circle Count "
    "(number of LSBs per full rotation about line "
    "axis)\"}},\"type\":\"object\",\"description\":\"Angle Measurement Unit\"}},\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"requi"
    "red\":[\"primary\"],\"description\":\"Scanner device geometry "
    "details\",\"title\":\"Device Geometry\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[4,0]},\"secondary\":{\"content\":[0],\"ID\":"
    "[91,0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"primary\":{\"properties\":{\"content\":{\"type\":\"array\",\"des"
    "cription\":\"Internal calibration values\",\"items\":{\"type\":\"number\"}},\"ID"
    "\":{\"maxItems\":2,\"minItems\":2,\"type\":\"array\",\"description\":\"Structure i"
    "dentifier\",\"items\":{\"type\":\"integer\"}}},\"required\":[\"ID\",\"content\"],\"t"
    "ype\":\"object\",\"description\":\"Primary device geometry structure (mandat"
    "ory)\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"ob"
    "ject\",\"required\":[\"primary\"],\"description\":\"Scanner passive channel "
    "device geometry details\",\"title\":\"Device Geometry Passive Channel\"}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"background_radiation_maximum\":{\"type\":\"number\",\"descri"
    "ption\":\"Maximum possible background radiation.\"},\"reflectance_maximum\""
    ":{\"type\":\"number\",\"description\":\"Maximum possible reflectance in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"reflectance_minimum\":{\"type\":\"numbe"
    "r\",\"description\":\"Minimum possible reflectance in "
    "dB.\"},\"mta_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " number of MTA "
    "zones.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in dB.\"},\"background_radiation_minimum\":{\"type\":\"nu"
    "mber\",\"description\":\"Minimum possible background radiation.\"},\"deviati"
    "on_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible pulse "
    "shape "
    "deviation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in meters.\"}},\"type\":\"object\",\"description\":\"Limits of "
    "the measured values output by the device. The limits depend on the "
    "device type, measurement program and/or scan pattern.\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":100.0,\"background_radiation_minimum\":0,\"deviation"
    "_minimum\":-1,\"deviation_maximum\":32767,\"amplitude_minimum\":0.0,\"reflec"
    "tance_minimum\":-100.0,\"reflectance_maximum\":100.0,\"range_maximum\":1000"
    "0.0,\"background_radiation_maximum\":0,\"mta_zone_count_maximum\":7,\"range"
    "_minimum\":2.9}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"properties\":{\"signed\":{\"type\":\"boolean\",\"des"
    "cription\":\"Flag that is set when the original 'riegl.device' entry in "
    "the source file was correctly "
    "signed.\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"channel_number\":{\"minimum\":0,\"exclusiveMinimum\":false,\"typ"
    "e\":\"integer\",\"description\":\"Laser channel number (not defined or 0: "
    "single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel devices)\"}"
    "},\"required\":[\"device_type\",\"serial_number\"],\"type\":\"object\"},\"descrip"
    "tion\":\"Details about the devices used to acquire the point cloud (e.g."
    " when merging point clouds of different devices)\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"title\":\"Devices Information\"}"
    ,
    /* example: */
    "[{\"signed\":false,\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\","
    "\"device_type\":\"VZ-400i\",\"device_build\":\"\",\"channel_number\":0,\"channel_"
    "text\":\"\"},{\"signed\":true,\"device_name\":\"Scanner 2\",\"serial_number\":\"S2"
    "222680\",\"device_type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"channel_number\""
    ":1,\"channel_text\":\"\"},{\"signed\":true,\"device_name\":\"Scanner 3\",\"serial"
    "_number\":\"S2222680\",\"device_type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"cha"
    "nnel_number\":2,\"channel_text\":\"\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"post\":{\"properties\":{\"a\":{\"maxItems\":2080,\"minItems\":1"
    ",\"type\":\"array\",\"description\":\"...\",\"items\":{\"type\":\"number\"}},\"nc\":{\""
    "minimum\":0,\"maximum\":255,\"type\":\"integer\",\"description\":\"Number of ent"
    "ries\"}},\"required\":[\"nc\",\"a\"],\"type\":\"object\",\"description\":\"Dyntrig "
    "post values\"},\"tab\":{\"maxItems\":128,\"minItems\":1,\"type\":\"array\",\"descr"
    "iption\":\"...\",\"items\":{\"properties\":{\"dec2\":{\"type\":\"number\",\"descript"
    "ion\":\"Rise of pre-trigger threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of dB\"}},\"required\":[\"thra1\",\"del1\",\"dec1\",\"thra2\","
    "\"del2\",\"dec2\"],\"type\":\"object\",\"description\":\"...\"}},\"scale\":{\"type\":\""
    "number\",\"description\":\"Scale in units of dB, for calculation of line: "
    "line number N=(amplitude-offset)/scale\"},\"pre\":{\"properties\":{\"a\":{\"ma"
    "xItems\":2080,\"minItems\":1,\"type\":\"array\",\"description\":\"...\",\"items\":{"
    "\"type\":\"number\"}},\"nc\":{\"minimum\":0,\"maximum\":255,\"type\":\"integer\",\"de"
    "scription\":\"Number of entries\"}},\"required\":[\"nc\",\"a\"],\"type\":\"object\""
    ",\"description\":\"Dyntrig pre "
    "values\"},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units of "
    "dB, for calculation of line\"}},\"description\":\"Dyntrig\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"title\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"post\":{\"a\":[78,86,126,134,31],\"nc\":128},\"tab\":[{\"dec2\":0.0,\"del2\":0."
    "0,\"dec1\":0.0,\"del1\":0.0,\"thra1\":0.0,\"thra2\":0.0}],\"scale\":1.0,\"pre\":{\""
    "a\":[78,86,126,134,31],\"nc\":128},\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"echo_file\":{\"properties\":{\"file_uuid\":{\"type\":\"string\""
    ",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"],\"t"
    "ype\":\"object\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"t"
    "ype\":\"object\",\"required\":[\"echo_file\"],\"description\":\"Details about "
    "echo files\",\"title\":\"Echo Information\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/channel\",\"desc"
    "ription\":\"one field per channel, field name is channel index\"}},\"defin"
    "itions\":{\"channel\":{\"properties\":{\"a_lin\":{\"exclusiveMinimum\":false,\"t"
    "ype\":\"number\",\"exclusiveMaximum\":false,\"minimum\":0,\"maximum\":1,\"descri"
    "ption\":\"relative linear amplitude range "
    "[0..1]\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude "
    "calibration\"},\"delay\":{\"type\":\"number\",\"description\":\"delay "
    "calibration in seconds\"},\"parameter\":{\"properties\":{\"A\":{\"type\":\"array"
    "\",\"description\":\"real part of amplitude factor in units of full-scale\""
    ",\"items\":{\"type\":\"number\"}},\"B\":{\"type\":\"array\",\"description\":\"imagina"
    "ry part of amplitude factor in units of full-scale\",\"items\":{\"type\":\"n"
    "umber\"}},\"omega\":{\"type\":\"array\",\"description\":\"angular frequency in H"
    "z\",\"items\":{\"type\":\"number\"}},\"gamma\":{\"type\":\"array\",\"description\":\"d"
    "ecay in 1/second\",\"items\":{\"type\":\"number\"}}},\"required\":[\"A\",\"B\",\"gam"
    "ma\",\"omega\"],\"type\":\"object\",\"description\":\"parameters of the syswave "
    "exponential sum\"}},\"required\":[\"delay\",\"scale\",\"parameter\"],\"type\":\"ob"
    "ject\"}},\"type\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"additionalProperties\":false,\"description\":\"Details for "
    "exponential decomposition of full waveform data\",\"title\":\"Exponential "
    "Decomposition\"}"
    ,
    /* example: */
    "{\"0\":{\"a_lin\":0.27,\"scale\":1.0,\"delay\":3.783458418887631e-09,\"paramete"
    "r\":{\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515747],\"B\""
    ":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361],\"omega\""
    ":[352020896.0,3647927552.0,-1977987072.0],\"gamma\":[-1094726528.0,-7695"
    "62752.0,-848000064.0]}},\"1\":{\"a_lin\":0.9,\"scale\":1.0,\"delay\":3.5e-09,\""
    "parameter\":{\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,0.0,-0.3],\"omega\":[352020896."
    "0,3647927552.0,-1977987072.0],\"gamma\":[-1094726528.0,-769562752.0,-848"
    "000064.0]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude_lsb_low_power\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}"
    "},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}"
    "},\"range_offset_sec_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"numbe"
    "r\"}},\"range_offset_sec_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"num"
    "ber\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"ob"
    "ject\",\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\""
    ",\"amplitude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_po"
    "wer\"],\"description\":\"riegl.gaussian_decomposition contains information"
    " relevant for extracting calibrated amplitudes and calibrated ranges "
    "from a Gaussian decomposition of full waveform data. This information "
    "is contained in a table with five columns. Two columns are to be used "
    "as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The "
    "other three columns provide the outputs. Amplitude_db gives the "
    "calibrated amplitude in the optical regime in decibels. The range "
    "offset columns provide additive range offsets, given in units of "
    "seconds, for each channel.\",\"title\":\"Gaussian Decomposition\"}"
    ,
    /* example: */
    "{\"amplitude_lsb_low_power\":[],\"amplitude_db\":[],\"amplitude_lsb_high_po"
    "wer\":[],\"range_offset_sec_high_power\":[],\"range_offset_sec_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"crs\":{\"properties\":{\"wkt\":{\"type\":\"string\",\"descriptio"
    "n\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http://www.openge"
    "ospatial.org/standards/wkt-crs)\"},\"epsg\":{\"minimum\":0,\"type\":\"integer\""
    ",\"description\":\"EPSG "
    "code\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference "
    "system name\"}},\"type\":\"object\",\"description\":\"Global Coordinate "
    "Reference System. Please note that only 3D Cartesian Coordinate "
    "Systems are allowed.\"},\"pose\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array"
    "\",\"description\":\"Coordinate Transformation Matrix to transform from "
    "File Coordinate System to Global Coordinate Reference System. 4x4 "
    "matrix stored as two dimensional array, row major order.\",\"items\":{\"ma"
    "xItems\":4,\"minItems\":4,\"type\":\"array\",\"description\":\"rows\",\"items\":{\"t"
    "ype\":\"number\",\"description\":\"columns\"}}}},\"type\":\"object\",\"description"
    "\":\"Point cloud georeferencing information\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"epsg\":4978,\"name\":\"WGS84 Geocentr"
    "ic\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Geometric scale "
    "factor applied to point coordinates\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"type\":\"number\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"trajectory_file\":{\"properties\":{\"file_uuid\":{\"type\":\"s"
    "tring\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"],\"type\":\"object\",\"description\":\"Trajectory data used for "
    "georeferencing of the point cloud\"},\"trajectory_offsets\":{\"properties\""
    ":{\"offset_north\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_height\""
    ":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_pitch\":{\"type\":\"number\""
    ",\"description\":\"[deg]\"},\"offset_east\":{\"type\":\"number\",\"description\":\""
    "[m]\"},\"offset_roll\":{\"type\":\"number\",\"description\":\"[deg]\"},\"version\":"
    "{\"type\":\"integer\",\"description\":\"Meaning of offset values and how to "
    "apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[deg]"
    "\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"}},\"type\":\"object"
    "\",\"description\":\"Correction offsets applied to the trajectory data\"},\""
    "body_coordinate_system_type\":{\"enum\":[\"NED\",\"ENU\"],\"type\":\"string\",\"de"
    "scription\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\"},\"socs_to_body_matrix\":{\"maxItems\":4,\"mi"
    "nItems\":4,\"type\":\"array\",\"description\":\"Coordinate Transformation "
    "Matrix to transform from Scanner's Own Coordinate System to Body "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\",\"items\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array\",\"descr"
    "iption\":\"rows\",\"items\":{\"type\":\"number\",\"description\":\"columns\"}}},\"so"
    "cs_to_rocs_matrix\":{\"maxItems\":4,\"minItems\":4,\"type\":\"array\",\"descript"
    "ion\":\"Coordinate Transformation Matrix to transform from Scanner's Own"
    " Coordinate System to Record Coordinate System. 4x4 matrix stored as "
    "two dimensional array, row major order.\",\"items\":{\"maxItems\":4,\"minIte"
    "ms\":4,\"type\":\"array\",\"description\":\"rows\",\"items\":{\"type\":\"number\",\"de"
    "scription\":\"columns\"}}}},\"type\":\"object\",\"description\":\"Parameters "
    "used for georeferencing of the point cloud\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"trajectory_offsets\":{\"offset_north\":0.07,\"o"
    "ffset_height\":-0.2,\"offset_pitch\":0.01,\"offset_east\":0.15,\"offset_roll"
    "\":0.03,\"version\":0,\"offset_yaw\":-0.45,\"offset_time\":18.007},\"body_coor"
    "dinate_system_type\":\"NED\",\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]]}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"description\":\"One "
    "field per item, field name is item id, field value is item "
    "name\"}},\"additionalProperties\":false,\"description\":\"Map of item "
    "names\",\"title\":\"Item Names\"}"
    ,
    /* example: */
    "{\"47\":\"Name of item with id 47\",\"2\":\"Name of item with id "
    "2\",\"-1\":\"Name of item with id -1\",\"1\":\"Name of item with id 1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "patternProperties\":{\"^.*$\":{\"minItems\":1,\"type\":\"array\",\"description\":"
    "\"Each field of the object represents a feature and holds a list of "
    "license keys, where the field name is the feature "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"License key (example: "
    "'46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"}}},\"additionalProperties\":false,\"description\":\"License "
    "keys for software features\",\"title\":\"Software License Keys\"}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography with GPU support\":[\"8AB44126 - "
    "23B92250 - 16E2689F - 34EF7E7B\"],\"MTA resolution\":[\"468E020A - "
    "39A922E4 - B681A184 - 673E3D72\"],\"Full Waveform Analysis "
    "Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"modulation_depth\":{\"minimum\":0,\"type\":\"number\",\"descri"
    "ption\":\"Depth of pulse position modulation in meter.\"},\"zone_width\":{\""
    "minimum\":0,\"type\":\"number\",\"description\":\"Width of a MTA zone in meter"
    ".\"},\"zone_count\":{\"minimum\":0,\"maximum\":255,\"type\":\"integer\",\"descript"
    "ion\":\"Maximum number of MTA "
    "zones.\"}},\"type\":\"object\",\"description\":\"Parameters for MTA processing"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"MTA "
    "Settings\"}"
    ,
    /* example: */
    "{\"modulation_depth\":9.368514,\"zone_width\":149.896225,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 m\"},\"content\":{\"maxItem"
    "s\":2000,\"minItems\":1,\"type\":\"array\",\"description\":\"Correction value "
    "[m] to be added to the raw range\",\"items\":{\"type\":\"number\"}}},\"$schema"
    "\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\""
    ":[\"delta\",\"content\"],\"description\":\"Lookup table for range correction "
    "based on raw range\",\"title\":\"Near Range Correction Table\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude_sigma\":{\"type\":\"array\",\"description\":\"Sigma "
    "amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"type\":\"array\""
    ",\"description\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"range_sigm"
    "a\":{\"type\":\"array\",\"description\":\"Sigma range [m]\",\"items\":{\"type\":\"nu"
    "mber\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"o"
    "bject\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"descr"
    "iption\":\"Standard deviation for range and amplitude as a function of "
    "amplitude\",\"title\":\"Noise Estimates\"}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10"
    ".0],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"amplitude_maximum\":{\"minimum\":0,\"type\":\"number\",\"descr"
    "iption\":\"Maximum amplitude "
    "[dB]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range [m"
    "]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"objec"
    "t\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"d"
    "escription\":\"Notch filter parameters for window glass "
    "echoes\",\"title\":\"Notch Filter\"}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"descrip"
    "tion\":\"Size of pixels in a locally levelled cartesian coordinate "
    "system (xy). This is only used for pixels based on a map projection.\"}"
    ",\"size\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of "
    "pixels in file coordinate system.\"}},\"definitions\":{\"pixel_size\":{\"max"
    "Items\":2,\"minItems\":2,\"type\":\"array\",\"description\":\"Size of "
    "pixels.\",\"items\":{\"minimum\":0,\"type\":\"number\",\"description\":\"Length of"
    " pixel edge [m].\"}}},\"type\":\"object\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"required\":[\"size\"],\"description\":\"Details about "
    "the pixels contained in the file\",\"title\":\"Pixel Information\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"plane_patch_file_two\":{\"$ref\":\"#/definitions/file_refe"
    "rence\",\"description\":\"Reference to the plane patch file two\"},\"plane_p"
    "atch_file_one\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"R"
    "eference to the plane patch file one\"}},\"definitions\":{\"file_reference"
    "\":{\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane "
    "patch file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}},\"required\":[\"file_uuid\",\"file"
    "_path\"],\"type\":\"object\",\"description\":\"Reference to a plane patch file"
    "\"}},\"type\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\",\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"descript"
    "ion\":\"Details about the plane patch matching process\",\"title\":\"Plane "
    "Patch Matching\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fb"
    "efa9\",\"file_path\":\"project.ptch\"},\"plane_patch_file_one\":{\"file_uuid\":"
    "\"810f5d57-eccf-49ed-b07a-0cdd109b4213\",\"file_path\":\"Record009_Line001/"
    "191025_121410_Scanner_1.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"total_horizontal_area\":{\"type\":\"number\",\"description\":"
    "\"sum of all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of all "
    "plane patch areas "
    "[m\\u00b2]\"}},\"type\":\"object\",\"description\":\"Statistics about plane "
    "patches found by plane patch extractor\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"settings\":{\"type\":\"object\",\"description\":\"Classificati"
    "on settings, details see documentation of rdbplanes\",\"oneOf\":[{\"$ref\":"
    "\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method-2\"}]},\"classes"
    "\":{\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one"
    " field per class, field name is class number, field value is class nam"
    "e\"}},\"additionalProperties\":false,\"type\":\"object\",\"description\":\"Class"
    " definition table\"}},\"definitions\":{\"method-1\":{\"properties\":{\"plane_c"
    "lassification_method\":{\"minimum\":1,\"maximum\":1,\"type\":\"integer\",\"descr"
    "iption\":\"method ID (=1)\"},\"maximum_inclination_angle_horizontal\":{\"min"
    "imum\":-360.0,\"maximum\":360.0,\"type\":\"number\",\"description\":\"maximum "
    "inclination angle of horizontal plane patches [deg]\"}},\"required\":[\"pl"
    "ane_classification_method\",\"maximum_inclination_angle_horizontal\"],\"ty"
    "pe\":\"object\",\"description\":\"Classification method 1\"},\"method-2\":{\"pro"
    "perties\":{\"sloping_plane_classes_minimum_angle\":{\"minimum\":-360.0,\"max"
    "imum\":360.0,\"type\":\"number\",\"description\":\"minimum inclination angle "
    "of sloping plane patches [deg]\"},\"plane_classification_method\":{\"minim"
    "um\":2,\"maximum\":2,\"type\":\"integer\",\"description\":\"method ID (=2)\"},\"sl"
    "oping_plane_classes_maximum_angle\":{\"minimum\":-360.0,\"maximum\":360.0,\""
    "type\":\"number\",\"description\":\"maximum inclination angle of sloping "
    "plane patches [deg]\"}},\"required\":[\"plane_classification_method\",\"slop"
    "ing_plane_classes_minimum_angle\",\"sloping_plane_classes_maximum_angle\""
    "],\"type\":\"object\",\"description\":\"Classification method 2\"}},\"type\":\"ob"
    "ject\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":["
    "\"settings\",\"classes\"],\"description\":\"Settings and classes for plane "
    "slope classification\",\"title\":\"Plane Slope Class Info\"}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_minimum_angle\":10.0,\"plane_classif"
    "ication_method\":2,\"sloping_plane_classes_maximum_angle\":70.0},\"classes"
    "\":{\"12\":\"sloping, pointing down and north\",\"6\":\"vertical, pointing "
    "east\",\"7\":\"vertical, pointing south\",\"3\":\"sloping, pointing up and "
    "south\",\"5\":\"sloping, pointing up and west\",\"4\":\"sloping, pointing up "
    "and north\",\"13\":\"sloping, pointing down and west\",\"8\":\"vertical, "
    "pointing north\",\"10\":\"sloping, pointing down and east\",\"9\":\"vertical, "
    "pointing west\",\"2\":\"sloping, pointing up and east\",\"11\":\"sloping, "
    "pointing down and south\",\"1\":\"horizontal, pointing "
    "up\",\"14\":\"horizontal, pointing down\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "patternProperties\":{\"^.*$\":{\"minItems\":1,\"type\":\"array\",\"description\":"
    "\"Each field of the object represents a point attribute group and holds"
    " a list of point attributes, where the field name is the group "
    "name.\",\"items\":{\"type\":\"string\",\"description\":\"Point attribute full "
    "name or name pattern (perl regular expression "
    "syntax)\"}}},\"additionalProperties\":false,\"description\":\"Grouping and "
    "sorting of point attributes for visualization purposes\",\"title\":\"Point"
    " Attribute Groups\"}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.thet"
    "a\",\"riegl.phi\"],\"Time\":[\"riegl.timestamp\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"field_of_application\":{\"enum\":[\"unknown\",\"SLS\",\"TLS\",\""
    "KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"type\":\"string\",\"description\":\"Fie"
    "ld of application\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"comments\":{\"type\":\"string\",\"description\":\"Comments\"}},\"type\":\""
    "object\",\"description\":\"Details about point cloud files\",\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"title\":\"Point Cloud "
    "Information\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"barometric_height_amsl\":{\"type\":\"number\",\"description\""
    ":\"Altitude determined based on the atmospheric pressure according to "
    "the standard atmosphere laws [m].\"},\"orientation\":{\"properties\":{\"pitc"
    "h\":{\"minimum\":-360,\"maximum\":360,\"type\":\"number\",\"description\":\"Pitch "
    "angle about scanner Y-axis [deg]\"},\"pitch_accuracy\":{\"minimum\":0,\"excl"
    "usiveMinimum\":true,\"type\":\"number\",\"description\":\"Pitch angle accuracy"
    " [deg]\"},\"roll_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\""
    "number\",\"description\":\"Roll angle accuracy [deg]\"},\"roll\":{\"minimum\":-"
    "360,\"maximum\":360,\"type\":\"number\",\"description\":\"Roll angle about "
    "scanner X-axis [deg]\"},\"yaw\":{\"minimum\":-360,\"maximum\":360,\"type\":\"num"
    "ber\",\"description\":\"Yaw angle about scanner Z-axis [deg]\"},\"yaw_accura"
    "cy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"description\""
    ":\"Yaw angle accuracy [deg]\"}},\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_a"
    "ccuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"type\":\"object\",\"description"
    "\":\"Orientation values and orientation accuracies, measured with IMU or"
    " inclination sensors.\"},\"position\":{\"properties\":{\"vertical_accuracy\":"
    "{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"description\":\"Ve"
    "rtical accuracy "
    "[m]\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"horizon"
    "tal_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"de"
    "scription\":\"Horizontal accuracy "
    "[m]\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 as "
    "defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate "
    "1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\"},\"crs"
    "\":{\"properties\":{\"epsg\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"E"
    "PSG code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"required\":[\"epsg\"],\"type\":\"object\",\"description\":\"Global "
    "Coordinate Reference System\"}},\"required\":[\"coordinate_1\",\"coordinate_"
    "2\",\"coordinate_3\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"ty"
    "pe\":\"object\",\"description\":\"Position coordinates and position accuracy"
    " values as measured by GNSS in the specified Coordinate Reference "
    "System (CRS)\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"t"
    "ype\":\"object\",\"required\":[\"orientation\"],\"description\":\"Estimated "
    "position and orientation information as measured by GNSS, IMU or "
    "inclination sensors\",\"title\":\"Pose Estimation\"}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"pitch\":1.5"
    "09153024827064,\"pitch_accuracy\":0.009433783936875745,\"roll_accuracy\":0"
    ".009433783936875745,\"roll\":3.14743073066123,\"yaw\":101.87293630292045,\""
    "yaw_accuracy\":1.0094337839368757},\"position\":{\"vertical_accuracy\":1.33"
    "14999341964722,\"coordinate_2\":15.645033406,\"horizontal_accuracy\":0.810"
    "699999332428,\"coordinate_3\":362.7124938964844,\"coordinate_1\":48.655799"
    "473,\"crs\":{\"epsg\":4979,\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WG"
    "S84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\","
    "\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.000000"
    "0000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251"
    "994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS["
    "\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"}}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"gyroscope\":{\"properties\":{\"z_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle ="
    " 0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"minimum\":0,\"exclusiveMin"
    "imum\":true,\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to "
    "be subtracted from raw measurement values\"}},\"required\":[\"unit\",\"x_axi"
    "s\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\""
    ":\"object\",\"description\":\"Gyroscope details\"},\"accelerometer\":{\"propert"
    "ies\":{\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = "
    "0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"minimum\":0,\"exclusiveMin"
    "imum\":true,\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"relative_nonlinearity\":"
    "{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, d"
    "imensionless\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\""
    "Value to be subtracted from raw measurement values\"}},\"required\":[\"uni"
    "t\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity"
    "\"],\"type\":\"object\",\"description\":\"Accelerometer details\"},\"magnetic_fi"
    "eld_sensor\":{\"properties\":{\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"de"
    "scription\":\"Sensitive Z axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner part\"},\"unit\":{\"minim"
    "um\":0,\"exclusiveMinimum\":true,\"type\":\"number\",\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in nT\"},\"relative_nonlinearity\""
    ":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, "
    "dimensionless\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":"
    "\"Value to be subtracted from raw measurement values\"}},\"required\":[\"un"
    "it\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity"
    "\"],\"type\":\"object\",\"description\":\"Magnetic Field Sensor details\"}},\"de"
    "finitions\":{\"vector\":{\"maxItems\":3,\"minItems\":3,\"type\":\"array\",\"items\""
    ":{\"type\":\"number\",\"description\":\"Index 0=X, 1=Y, 2=Z component\"}}},\"ty"
    "pe\":\"object\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"requ"
    "ired\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"descripti"
    "on\":\"Details on position and orientation sensors\",\"title\":\"Pose "
    "Sensors\"}"
    ,
    /* example: */
    "{\"gyroscope\":{\"z_axis\":[0.555869996547699,119.22135162353516,0.4675850"
    "27217865],\"origin\":[0.026900000870227814,-0.03999999910593033,-0.08950"
    "000256299973],\"x_axis\":[-121.195556640625,0.8219714164733887,0.2313031"
    "703233719],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.589477"
    "5390625],\"unit\":0.00014544410805683583,\"relative_nonlinearity\":[2.8881"
    "76311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"offset\""
    ":[-50.92609786987305,146.15643310546875,62.4327278137207]},\"accelerome"
    "ter\":{\"z_axis\":[1.639882206916809,15166.744140625,-116.99742889404297]"
    ",\"origin\":[0.026900000870227814,-0.03999999910593033,-0.08950000256299"
    "973],\"x_axis\":[-15008.123046875,56.956390380859375,-60.5175666809082],"
    "\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.3701171875],\"uni"
    "t\":6.666666740784422e-05,\"relative_nonlinearity\":[0.0,0.0,0.0],\"offset"
    "\":[-733.3636474609375,58.969032287597656,1060.2550048828125]},\"magneti"
    "c_field_sensor\":{\"z_axis\":[0.00041987866279669106,7.876977906562388e-0"
    "5,0.011407104320824146],\"x_axis\":[-0.011162743903696537,-2.31596277444"
    "6234e-05,0.00016818844596855342],\"y_axis\":[0.00027888521435670555,-0.0"
    "11427424848079681,-5.204829722060822e-05],\"fixed\":[-1576.010498046875,"
    "1596.081787109375,0.0],\"unit\":91.74311828613281,\"relative_nonlinearity"
    "\":[0.0,0.0,0.0],\"offset\":[-23812.052734375,5606.57666015625,2493.28125"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"num_mod_ampl\":{\"minimum\":0,\"maximum\":255,\"type\":\"integ"
    "er\",\"description\":\"Number of different modulation amplitudes (2: "
    "binary "
    "modulation)\"},\"pulse_interval\":{\"type\":\"array\",\"description\":\"Explicit"
    " table of the pulse position modulation used for MTA resolution. Table"
    " gives times between successive laser pulses in seconds.\",\"items\":{\"mi"
    "nimum\":0,\"type\":\"number\"}},\"length\":{\"minimum\":0,\"maximum\":255,\"type\":"
    "\"integer\",\"description\":\"Length of code\"},\"code_phase_mode\":{\"minimum\""
    ":0,\"maximum\":255,\"type\":\"integer\",\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\"},\"phase_step\":{\"minimum\":0,\"maximum\":255,\"type\":\"integer\",\"d"
    "escription\":\"Step width in phase of modulation code from line to line\""
    "}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\""
    ",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"description\":\""
    "Laser pulse position modulation used for MTA "
    "resolution\",\"title\":\"Pulse Position Modulation\"}"
    ,
    /* example: */
    "{\"num_mod_ampl\":2,\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375"
    "e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,"
    "2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-"
    "06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.75937"
    "5e-06,2.821875e-06],\"length\":31,\"code_phase_mode\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum value\"}}"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"description\":\"Sta"
    "tistics about target distance wrt. SOCS origin\",\"title\":\"Range "
    "Statistics\"}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"average\":15.49738,\"std_dev\":24.349,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"tbl\":{\"minItems\":1,\"type\":\"array\",\"description\":\"vario"
    "us internal data\",\"items\":{\"$ref\":\"#/definitions/fp_table\"}},\"t\":{\"pat"
    "ternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"description\":\""
    "one field per channel, field name is channel index\"}},\"additionalPrope"
    "rties\":false,\"type\":\"object\"},\"sr\":{\"minimum\":0,\"exclusiveMinimum\":tru"
    "e,\"type\":\"number\",\"description\":\"Sample rate [Hz]\"},\"mw\":{\"minimum\":0,"
    "\"exclusiveMinimum\":true,\"maximum\":4095,\"type\":\"number\",\"description\":\""
    "Maximum weight\"},\"ns\":{\"minimum\":0,\"maximum\":4095,\"type\":\"integer\",\"de"
    "scription\":\"Number of "
    "samples\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\"},\"nt\":{\"minimum\":0,\"maximum"
    "\":255,\"type\":\"integer\",\"description\":\"Number of traces\"},\"a\":{\"maxItem"
    "s\":256,\"minItems\":1,\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"ite"
    "ms\":{\"type\":\"number\"}},\"si\":{\"minimum\":0,\"maximum\":255,\"type\":\"number\""
    ",\"description\":\"Start index (hw_start)\"}},\"definitions\":{\"fp\":{\"proper"
    "ties\":{\"w\":{\"maxItems\":256,\"minItems\":1,\"type\":\"array\",\"items\":{\"maxIt"
    "ems\":5,\"minItems\":5,\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"s\":{\"m"
    "axItems\":256,\"minItems\":1,\"type\":\"array\",\"items\":{\"maxItems\":4096,\"min"
    "Items\":1,\"type\":\"array\",\"items\":{\"type\":\"number\"}}}},\"required\":[\"s\",\""
    "w\"],\"type\":\"object\",\"description\":\"Fingerprint values\"},\"fp_table\":{\"p"
    "roperties\":{\"tv\":{\"minItems\":1,\"items\":{\"oneOf\":[{\"$ref\":\"#/definition"
    "s/fp_table_row\"},{\"type\":\"number\"}]},\"type\":\"array\",\"maxItems\":2048},\""
    "ny\":{\"description\":\"number of y entries\",\"min\":1,\"type\":\"integer\",\"max"
    "\":2048},\"ch\":{\"description\":\"channel "
    "number\",\"min\":0,\"type\":\"integer\",\"max\":255},\"tc\":{\"description\":\"table"
    " data type "
    "code\",\"min\":0,\"type\":\"integer\",\"max\":255},\"nx\":{\"description\":\"number "
    "of x entries\",\"min\":1,\"type\":\"integer\",\"max\":2048}},\"required\":[\"ch\",\""
    "tc\",\"nx\",\"ny\",\"tv\"],\"type\":\"object\",\"desription\":\"scanner internal dat"
    "a\"},\"fp_table_row\":{\"minItems\":1,\"items\":{\"type\":\"number\"},\"type\":\"arr"
    "ay\",\"maxItems\":2048}},\"type\":\"object\",\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"description\":\"Receiver "
    "Internals\",\"title\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"tbl\":[{\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"ny\":2,\"ch\":0,\"tc\":1"
    ",\"nx\":5}],\"t\":{\"0\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":[["
    "1.23,4.56],[7.89,0.12]]},\"1\":{\"w\":[[78,86,126,134,31],[78,86,126,134,3"
    "1]],\"s\":[[1.23,4.56],[7.89,0.12]]}},\"sr\":7959997000.0,\"mw\":31,\"ns\":400"
    ",\"nt\":128,\"a\":[-1.55],\"si\":48}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 m\"},\"content\":{\"maxItem"
    "s\":2000,\"minItems\":1,\"type\":\"array\",\"description\":\"Correction value "
    "[dB] to be added to the amplitude\",\"items\":{\"type\":\"number\"}}},\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required"
    "\":[\"delta\",\"content\"],\"description\":\"Lookup table for reflectance "
    "calculation based on amplitude and range\",\"title\":\"Reflectance "
    "Calculation Table\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"reflectance_correction_db\":{\"type\":\"array\",\"descriptio"
    "n\":\"Near range reflectance correction in dB as a function of range "
    "over angle\",\"items\":{\"type\":\"array\",\"description\":\"rows (each array "
    "corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an "
    "angle)\"}}},\"line_angles_deg\":{\"type\":\"array\",\"description\":\"Angle [deg"
    "]\",\"items\":{\"type\":\"number\"}},\"ranges_m\":{\"type\":\"array\",\"description\""
    ":\"Range [m]\",\"items\":{\"type\":\"number\"}}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"ranges_m\",\"line_an"
    "gles_deg\",\"reflectance_correction_db\"],\"description\":\"Range-dependent "
    "and scan-angle-dependent correction of reflectance "
    "reading\",\"title\":\"Near-range reflectance correction\"}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"segments\":{\"properties\":{\"list\":{\"type\":\"array\",\"items"
    "\":{\"properties\":{\"stop\":{\"minimum\":0.0,\"maximum\":720.0,\"type\":\"number\""
    ",\"description\":\"Stop angle in SOCS [deg]\"},\"increment\":{\"minimum\":0.0,"
    "\"maximum\":90.0,\"type\":\"number\",\"description\":\"Increment of angle in "
    "SOCS [deg]\"},\"start\":{\"minimum\":0.0,\"maximum\":360.0,\"type\":\"number\",\"d"
    "escription\":\"Start angle in SOCS [deg]\"}},\"required\":[\"start\",\"stop\",\""
    "increment\"],\"type\":\"object\",\"description\":\"Line Scan Segment\"}},\"progr"
    "am\":{\"$ref\":\"#/definitions/program\"}},\"required\":[\"list\"],\"type\":\"obje"
    "ct\",\"description\":\"Segmented Line Scan Pattern\"},\"line\":{\"properties\":"
    "{\"program\":{\"$ref\":\"#/definitions/program\"},\"stop\":{\"minimum\":0.0,\"max"
    "imum\":720.0,\"type\":\"number\",\"description\":\"Stop angle in SOCS [deg]\"},"
    "\"increment\":{\"minimum\":0.0,\"maximum\":90.0,\"type\":\"number\",\"description"
    "\":\"Increment of angle in SOCS [deg]\"},\"start\":{\"minimum\":0.0,\"maximum\""
    ":360.0,\"type\":\"number\",\"description\":\"Start angle in SOCS [deg]\"}},\"re"
    "quired\":[\"start\",\"stop\",\"increment\"],\"type\":\"object\",\"description\":\"Li"
    "ne Scan Pattern\"},\"rectangular\":{\"properties\":{\"theta_start\":{\"minimum"
    "\":0.0,\"maximum\":180.0,\"type\":\"number\",\"description\":\"Start theta angle"
    " in SOCS [deg]\"},\"phi_start\":{\"minimum\":0.0,\"maximum\":360.0,\"type\":\"nu"
    "mber\",\"description\":\"Start phi angle in SOCS [deg]\"},\"program\":{\"$ref\""
    ":\"#/definitions/program\"},\"phi_increment\":{\"minimum\":0.0,\"maximum\":90."
    "0,\"type\":\"number\",\"description\":\"Increment of phi angle in SOCS [deg]\""
    "},\"theta_increment\":{\"minimum\":0.0,\"maximum\":90.0,\"type\":\"number\",\"des"
    "cription\":\"Increment of theta angle in SOCS [deg]\"},\"theta_stop\":{\"min"
    "imum\":0.0,\"maximum\":180.0,\"type\":\"number\",\"description\":\"Stop theta "
    "angle in SOCS [deg]\"},\"phi_stop\":{\"minimum\":0.0,\"maximum\":720.0,\"type\""
    ":\"number\",\"description\":\"Stop phi angle in SOCS [deg]\"}},\"required\":[\""
    "phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"thet"
    "a_increment\"],\"type\":\"object\",\"description\":\"Rectangular Field Of View"
    " Scan Pattern\"}},\"definitions\":{\"program\":{\"properties\":{\"laser_prr\":{"
    "\"minimum\":0,\"exclusiveMinimum\":false,\"type\":\"number\",\"description\":\"La"
    "ser Pulse Repetition Rate "
    "[Hz]\"},\"name\":{\"type\":\"string\",\"description\":\"Name of measurement prog"
    "ram\"}},\"required\":[\"name\"],\"type\":\"object\",\"description\":\"Measurement "
    "program\"}},\"description\":\"Scan pattern description\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"title\":\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_start\":30.0,\"phi_start\":45.0,\"program\":{\"laser_"
    "prr\":100000.0,\"name\":\"High Speed\"},\"phi_increment\":0.04,\"theta_increme"
    "nt\":0.04,\"theta_stop\":130.0,\"phi_stop\":270.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"shot_file\":{\"properties\":{\"file_uuid\":{\"type\":\"string\""
    ",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"],\"t"
    "ype\":\"object\"}},\"type\":\"object\",\"description\":\"Details about laser "
    "shot files\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title"
    "\":\"Shot Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"activated\":{\"type\":\"boolean\",\"description\":\"Apply "
    "('true') or ignore ('false') all "
    "filters\"},\"filters\":{\"type\":\"array\",\"description\":\"List of point filte"
    "rs\",\"items\":{\"properties\":{\"activated\":{\"type\":\"boolean\",\"description\""
    ":\"Apply ('true') or ignore ('false') this "
    "filter\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter "
    "title (e.g. for display in a selection list)\"}},\"required\":[\"activated"
    "\",\"title\",\"description\",\"filter\"],\"type\":\"object\",\"description\":\"Point"
    " filter definition\"}}},\"$schema\":\"http://json-schema.org/draft-04/sche"
    "ma#\",\"type\":\"object\",\"required\":[\"activated\",\"filters\"],\"description\":"
    "\"Point filters applied in addition to the application-defined "
    "filters\",\"title\":\"Stored filters\"}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"activated\":false,\"filter\":\"riegl.mta_un"
    "certain_point == 0\",\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\",\"title\":\"Ignore uncertain points from MTA resolution\""
    "},{\"activated\":false,\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"title\":\"Ignore points below dynamic trigger "
    "level\"},{\"activated\":false,\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"title\":\"Ignore points outside outer "
    "AABB\"},{\"activated\":false,\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"title\":\"Ignore points inside inner AABB\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"timestamp\":{\"type\":\"string\",\"description\":\"Date and "
    "time of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"type\":\""
    "object\",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the "
    "document\"},\"version\":{\"type\":\"string\",\"description\":\"Document format v"
    "ersion\"},\"$class\":{\"enum\":[\"Document\"],\"type\":\"string\",\"description\":\""
    "Object class name\"}},\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"type\":\"object\",\"required\":[\"$class\",\"version\",\"author\",\"timestamp\""
    ",\"system\"],\"description\":\"Details of major system components like "
    "lidar sensors, cameras and navigation devices\",\"title\":\"System "
    "Description\"}"
    ,
    /* example: */
    "{\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System Description\"},\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"version\":\"1.2.1\",\"$class\":\"Document\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitions/conversio"
    "n_table\",\"description\":\"Conversion table for InGaAs - Si difference\"},"
    "\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Conversio"
    "n table for Si channel\"},\"InGaAs\":{\"$ref\":\"#/definitions/conversion_ta"
    "ble\",\"description\":\"Conversion table for InGaAs channel\"}},\"definition"
    "s\":{\"conversion_table\":{\"properties\":{\"temperature\":{\"type\":\"array\",\"d"
    "escription\":\"Temperature [\\u00b0C]\",\"items\":{\"type\":\"number\"}},\"value\""
    ":{\"type\":\"array\",\"description\":\"LSB [1]\",\"items\":{\"type\":\"number\"}}},\""
    "required\":[\"value\",\"temperature\"],\"type\":\"object\"}},\"type\":\"object\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Conve"
    "rsion of background radiation raw values to temperatures in "
    "\\u00b0C\",\"title\":\"Temperature Calculation Table\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]},\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478"
    "247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172"
    "555057597,319.2207163725366,321.2021611858325,323.3157023200148],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"source\":{\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"type\":\"strin"
    "g\",\"description\":\"Timestamp "
    "source\"},\"epoch\":{\"type\":\"string\",\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)"
    ".\"},\"system\":{\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\"type\":\"string\",\"descript"
    "ion\":\"Time system (time standard)\"}},\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"type\":\"object\",\"required\":[\"epoch\",\"source\"],\"desc"
    "ription\":\"Base of timestamps (epoch)\",\"title\":\"Time Base\"}"
    ,
    /* example: */
    "{\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"settings\":{\"type\":\"string\",\"description\":\"Settings "
    "used to calculate the trajectory (descriptive text)\"},\"navigation_fram"
    "e\":{\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"type\":\"string\",\"description\":\"Navi"
    "gation frame (NED: North-East-Down, ENU: "
    "East-North-Up)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. "
    "name/type/serial\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"software\":{\"type\":\"string\",\"descr"
    "iption\":\"Software that calculated the trajectory (this may be the same"
    " or different software than the one that created the file)\"},\"field_of"
    "_application\":{\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\""
    "BLS\",\"ILS\"],\"type\":\"string\",\"description\":\"Field of "
    "application\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"company\":{\"type\":\"string\",\"description\":\"Company name\"},\"time_"
    "interval\":{\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Min"
    "imum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time"
    " interval [s]\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],"
    "\"type\":\"object\",\"description\":\"Time interval statistics\"}},\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\""
    "time_interval\",\"navigation_frame\"],\"description\":\"Details about "
    "position+orientation files\",\"title\":\"Trajectory Information\"}"
    ,
    /* example: */
    "{\"settings\":\"default\",\"navigation_frame\":\"NED\",\"device\":\"IMU Model "
    "12/1, Serial# 12345\",\"location\":\"Horn\",\"software\":\"Navigation Software"
    " XYZ\",\"field_of_application\":\"MLS\",\"project\":\"Campaign "
    "3\",\"company\":\"RIEGL LMS\",\"time_interval\":{\"minimum\":0.00500032,\"averag"
    "e\":0.00500053,\"std_dev\":5.51e-07,\"maximum\":0.005004883}}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"output_usage\":{\"minimum\":0,\"type\":\"integer\",\"descripti"
    "on\":\"0 .. no output, 1 .. output derived from internal clock, 2 .. "
    "output derived from dmi, 3 .. output derived from external signal, 4 "
    ".. output static low, 5 .. output static high\"},\"in_max_duration\":{\"mi"
    "nimum\":0,\"type\":\"integer\",\"description\":\"stops measurement of pulse "
    "duration of input signal [0.1 "
    "msec]\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment in "
    "ticks\"},\"ext_subdivider\":{\"minimum\":0,\"type\":\"integer\",\"description\":\""
    "reduces the frequency, default "
    "1\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive string\""
    "},\"ext_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"external "
    "trigger, time delay [0.1 msec]\"},\"ttip_version\":{\"minimum\":0,\"type\":\"i"
    "nteger\",\"description\":\"following main.sub.ss.sss\"},\"dmi_min_time\":{\"mi"
    "nimum\":0,\"type\":\"integer\",\"description\":\"dmi, minimum time interval "
    "between trigger events [0.1 "
    "msec]\"},\"in_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\"},\"out_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\"},\"out_num_pulses\":{\"minimum\":0,\""
    "type\":\"integer\",\"description\":\"number of output pulses to be "
    "generated, 0 .. infinite\"},\"out_duration\":{\"minimum\":0,\"type\":\"integer"
    "\",\"description\":\"output pulse duration [0.1 "
    "msec]\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\"},\"ext_signal\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. "
    "use input signal, 1 .. use output signal of channel\"},\"out_delay\":{\"mi"
    "nimum\":0,\"type\":\"integer\",\"description\":\"output pulse initial delay "
    "after start [0.1 msec]\"},\"in_min_duration\":{\"minimum\":0,\"type\":\"intege"
    "r\",\"description\":\"input signals with smaller pulse durations are "
    "ignored [0.1 "
    "msec]\"},\"ext_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"input_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .."
    " deactivated, 1 .. just detecting and timestamping\"},\"channel\":{\"minim"
    "um\":0,\"type\":\"integer\",\"description\":\"ID of input/output channel\"},\"dm"
    "i_max_time\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"dmi, maximum "
    "time interval between trigger events [0.1 msec]\"},\"out_interval\":{\"min"
    "imum\":0,\"type\":\"integer\",\"description\":\"output pulse interval [0.1 mse"
    "c]\"},\"in_max_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"maxim"
    "um delay to output pulse before fake event is generated [0.1 msec], "
    "zero indicates that no fake events are generated\"},\"num_channel\":{\"min"
    "imum\":0,\"type\":\"integer\",\"description\":\"number of input/output "
    "channels\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive s"
    "tring\"},\"ext_bitmask\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"def"
    "ines which of the internal pulse generators are to be started\"}},\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"requir"
    "ed\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext_dela"
    "y\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_t"
    "ime\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr\",\"outpu"
    "t_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_interval\",\"o"
    "ut_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in_max_dur"
    "ation\",\"in_max_delay\"],\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"title\":\"TTIP Configuration\"}"
    ,
    /* example: */
    "{\"output_usage\":1,\"in_max_duration\":10000,\"dmi_incr\":0,\"ext_subdivider"
    "\":1,\"output_descr\":\"Port 1 - Trigger\",\"ext_delay\":0,\"ttip_version\":1,\""
    "dmi_min_time\":0,\"in_polarity\":0,\"out_polarity\":0,\"out_num_pulses\":1,\"o"
    "ut_duration\":300,\"dmi_dist_per_tick\":0.0,\"ext_signal\":0,\"out_delay\":0,"
    "\"in_min_duration\":0,\"ext_channel\":32,\"input_usage\":1,\"channel\":0,\"dmi_"
    "max_time\":0,\"out_interval\":10000,\"in_max_delay\":9990,\"num_channel\":9,\""
    "input_descr\":\"Port 1 - Exposure\",\"ext_bitmask\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"vertex_file\":{\"properties\":{\"file_uuid\":{\"type\":\"strin"
    "g\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"],\"t"
    "ype\":\"object\"}},\"type\":\"object\",\"description\":\"Details about vertex fi"
    "le\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Verte"
    "x Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "oneOf\":[{\"properties\":{\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_ori"
    "gin_enum\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref"
    "\":\"#/definitions/voxel_size_cubic\"}],\"description\":\"Size of voxels in "
    "file coordinate system.\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_ty"
    "pe\"},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"}},\"ad"
    "ditionalProperties\":false,\"required\":[\"size\",\"voxel_origin\",\"voxel_typ"
    "e\"]},{\"properties\":{\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"descrip"
    "tion\":\"Size of voxels in file coordinate system.\"},\"reference_point\":{"
    "\"maxItems\":2,\"minItems\":2,\"items\":{\"minimum\":-180,\"maximum\":180,\"type\""
    ":\"number\"},\"description\":\"Point in WGS84 geodetic decimal degree "
    "(EPSG:4326) that was used to compute the projection distortion "
    "parameters. The coefficient order is latitude, longitude. Only voxels "
    "with corresponding geo_tag, voxel_size and reference_point can be "
    "reliably processed together. This entry is available for voxel files "
    "in projected CRS only.\",\"type\":\"array\"},\"voxel_origin\":{\"oneOf\":[{\"$re"
    "f\":\"#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_ori"
    "gin_point\",\"description\":\"The base point of the voxel grid. Used "
    "together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute "
    "actual point coordinates.\"}]},\"size_llcs\":{\"$ref\":\"#/definitions/voxel"
    "_size\",\"description\":\"Size of voxels in a locally levelled cartesian "
    "coordinate system (xyz). This is only used for voxels based on a map p"
    "rojection.\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"shape_t"
    "hresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"}},\"additionalPrope"
    "rties\":false,\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_o"
    "rigin\",\"voxel_type\"]}],\"definitions\":{\"voxel_size\":{\"maxItems\":3,\"minI"
    "tems\":3,\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"description\":\"Si"
    "ze of voxels.\",\"type\":\"array\"},\"voxel_size_cubic\":{\"$ref\":\"#/definitio"
    "ns/edge_length\",\"type\":\"number\"},\"voxel_origin_point\":{\"maxItems\":3,\"m"
    "inItems\":3,\"items\":{\"type\":\"number\"},\"description\":\"Origin point for "
    "all voxel indices in voxel CRS.\",\"type\":\"array\"},\"voxel_origin_enum\":{"
    "\"enum\":[\"center\",\"corner\"],\"default\":\"corner\",\"description\":\"Defines "
    "whether the voxel's center or a corner is placed on CRS origin <tt>(0/"
    "0/0)</tt>.\"},\"edge_length\":{\"minimum\":0,\"exclusiveMinimum\":true,\"type\""
    ":\"number\",\"description\":\"Length of voxel edge [m].\"},\"voxel_type\":{\"en"
    "um\":[\"center\",\"centroid\",\"index\"],\"default\":\"centroid\",\"description\":\""
    "Whether a point in a voxel represents its center or its centroid. If "
    "type is <tt>index</tt> there is no point but only an integer voxel ind"
    "ex.\"},\"shape_thresholds\":{\"properties\":{\"line\":{\"minimum\":1,\"exclusive"
    "Minimum\":true,\"type\":\"number\",\"description\":\"If the biggest eigenvalue"
    " is bigger than the median eigenvalue * line_threshold, the voxel is "
    "considered a line.\"},\"plane\":{\"exclusiveMinimum\":true,\"type\":\"number\","
    "\"exclusiveMaximum\":true,\"minimum\":0,\"maximum\":1,\"description\":\"If the "
    "smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\"}},\"required\":[\"plan"
    "e\",\"line\"],\"type\":\"object\",\"description\":\"Thresholds used to compute "
    "the voxel's shape_id value.\"}},\"description\":\"Details about the voxels"
    " contained in the file\",\"title\":\"Voxel Information\"}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395,0.5143705304787237],\"re"
    "ference_point\":[48,16],\"voxel_origin\":\"corner\",\"size_llcs\":[0.51565752"
    "52891171,0.5130835356683303,0.5143705304787237],\"voxel_type\":\"centroid"
    "\",\"shape_thresholds\":{\"line\":6,\"plane\":0.16}}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"mta_zone\":{\"minimum\":1,\"type\":\"integer\",\"description\":"
    "\"Fixed MTA zone for averaging.\"},\"trim\":{\"minimum\":0,\"default\":0,\"maxi"
    "mum\":0.5,\"type\":\"number\",\"description\":\"Percentage for robust averagin"
    "g.\"},\"num_shots\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number "
    "of consecutive shots to be used for averaging.\"}},\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"num_shots"
    "\",\"mta_zone\"],\"description\":\"Settings for waveform "
    "averaging\",\"title\":\"Waveform Averaging Settings\"}"
    ,
    /* example: */
    "{\"mta_zone\":1,\"trim\":0.05,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibr"
    "ated device specific range offset for waveform analysis by system "
    "response fitting in meters.\"},\"range_offset_waveform_samples_m\":{\"type"
    "\":\"number\",\"description\":\"Calibrated device specific range offset for "
    "waveform samples in meters.\"},\"sample_block_file\":{\"properties\":{\"file"
    "_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"],\"type\":\"object\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"prop"
    "erties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"},\"sample_interval\":{\"minimum"
    "\":0,\"exclusiveMinimum\":false,\"type\":\"number\",\"description\":\"Sampling "
    "interval in seconds\"},\"laser_wavelength\":{\"minimum\":0,\"exclusiveMinimu"
    "m\":false,\"type\":\"number\",\"description\":\"Laser wavelength in meters (0 "
    "= unknown)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample "
    "data file extension, without the leading "
    "dot\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"channel\":{\"maximum\":255,\"type\":\"integer\",\"exclusiveMax"
    "imum\":false,\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"Sample"
    " block channel number (255 = invalid)\"},\"sample_bits\":{\"maximum\":32,\"t"
    "ype\":\"integer\",\"exclusiveMaximum\":false,\"minimum\":0,\"exclusiveMinimum\""
    ":false,\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 bit)\"},\"del"
    "ta_st\":{\"type\":\"number\",\"description\":\"reserved\"}},\"required\":[\"channe"
    "l\",\"channel_name\",\"sample_interval\",\"sample_bits\",\"laser_wavelength\",\""
    "delta_st\",\"file_extension\"],\"type\":\"object\"}}},\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"type\":\"object\",\"required\":[\"sample_block"
    "_file\",\"sample_data_files\"],\"description\":\"Details about waveform "
    "files\",\"title\":\"Waveform Information\"}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"sample_block_file\":{\"file_uuid\":\"93a03615-66"
    "c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"},\"range_offset_wavef"
    "orm_samples_m \":7.283,\"sample_data_files\":[{\"file_uuid\":\"da084413-e3e8"
    "-4655-a122-071de8490d8e\",\"sample_interval\":1.00503e-09,\"laser_waveleng"
    "th\":0,\"file_extension\":\"sp0\",\"channel_name\":\"high_power\",\"channel\":0,\""
    "sample_bits\":12,\"delta_st\":0},{\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7"
    "ba3be642d2\",\"sample_interval\":1.00503e-09,\"laser_wavelength\":0,\"file_e"
    "xtension\":\"sp1\",\"channel_name\":\"low_power\",\"channel\":1,\"sample_bits\":1"
    "2,\"delta_st\":0},{\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"s"
    "ample_interval\":1.00503e-09,\"laser_wavelength\":0,\"file_extension\":\"sp5"
    "\",\"channel_name\":\"wwf\",\"channel\":5,\"sample_bits\":12,\"delta_st\":0}]}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"properties\":{\"enabled\":{\"type\":\"boolean\",\"de"
    "scription\":\"Waveform output enabled\"},\"pass_ampl_greater\":{\"type\":\"num"
    "ber\",\"description\":\"Threshold for amplitude greater than "
    "[dB]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation greater than "
    "[1]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than [m]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name "
    "of sample block, e.g.: wfm, "
    "wwf\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation less than "
    "[1]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output enabled\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\""
    "],\"type\":\"object\"},\"description\":\"Scanner settings for waveform output"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Wavefor"
    "m Settings\"}"
    ,
    /* example: */
    "[{\"enabled\":true,\"pass_ampl_greater\":1.0,\"pass_rng_less\":13.11,\"sbl_na"
    "me\":\"wfm\",\"channel_idx_mask\":11,\"pass_rng_greater\":9.27,\"pass_ampl_les"
    "s\":5.0,\"smart_enabled\":true},{\"enabled\":false,\"sbl_name\":\"wwf\",\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"filter\":{\"properties\":{\"range_max\":{\"type\":\"array\",\"de"
    "scription\":\"[m]\",\"items\":{\"type\":\"number\"}},\"amplitude_max\":{\"type\":\"a"
    "rray\",\"description\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"angle\":{\"type\":"
    "\"array\",\"description\":\"[deg]\",\"items\":{\"type\":\"number\"}},\"range_min\":{"
    "\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}}},\"requir"
    "ed\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"],\"type\":\"object\"}"
    ",\"settings\":{\"properties\":{\"amplitude\":{\"properties\":{\"additive_value\""
    ":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}},\"required\":[\"sigm"
    "a_factor\",\"additive_value\"],\"type\":\"object\"},\"range\":{\"properties\":{\"a"
    "dditive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}},\"re"
    "quired\":[\"sigma_factor\",\"additive_value\"],\"type\":\"object\"}},\"required\""
    ":[\"range\",\"amplitude\"],\"type\":\"object\"},\"result\":{\"properties\":{\"range"
    "_mean\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},"
    "\"amplitude_mean\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"type\":"
    "\"number\"}},\"angle\":{\"type\":\"array\",\"description\":\"[deg]\",\"items\":{\"typ"
    "e\":\"number\"}},\"range_sigma\":{\"type\":\"array\",\"description\":\"[m]\",\"items"
    "\":{\"type\":\"number\"}},\"amplitude_offset\":{\"type\":\"array\",\"description\":"
    "\"[dB]\",\"items\":{\"type\":\"number\"}},\"amplitude_sigma\":{\"type\":\"array\",\"d"
    "escription\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"timestamp\":{\"type\":\"arr"
    "ay\",\"description\":\"[s]\",\"items\":{\"type\":\"number\"}}},\"required\":[\"angle"
    "\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"ampli"
    "tude_offset\"],\"type\":\"object\"}},\"$schema\":\"http://json-schema.org/draf"
    "t-04/schema#\",\"type\":\"object\",\"required\":[\"result\",\"filter\",\"settings\""
    "],\"description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"title\":\"Window Analysis\"}"
    ,
    /* example: */
    "{\"filter\":{\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43"
    ",0.431,0.431,0.432],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88"
    ",7.85,7.83,7.8,7.78],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,"
    "15.7,15.8,15.9],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,"
    "-0.219,-0.221,-0.223,-0.225,-0.227]},\"settings\":{\"amplitude\":{\"additiv"
    "e_value\":1.0,\"sigma_factor\":4},\"range\":{\"additive_value\":0.1,\"sigma_fa"
    "ctor\":8}},\"result\":{\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067"
    "261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.10312"
    "61],\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5.1"
    "16479,5.051756,4.983473,5.007885,5.002441,4.982],\"angle\":[14.9,15.0,15"
    ".1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"range_sigma\":[0.01869652,"
    "0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0.02"
    "225589,0.02229977,0.01899122,0.02009433],\"amplitude_offset\":[1.9,1.9],"
    "\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0"
    ".4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"timestamp"
    "\":[408.4441,411.4443]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"slices\":{\"type\":\"array\",\"items\":{\"properties\":{\"table\""
    ":{\"minItems\":1,\"type\":\"array\",\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"items\":{\"minItems\":1,\"type\":\"array\",\"description\":\"Table "
    "row (= amplitude axis)\",\"items\":{\"maxItems\":3,\"minItems\":3,\"type\":\"arr"
    "ay\",\"description\":\"Table column (= range "
    "axis)\",\"items\":{\"type\":\"number\",\"description\":\"Table cell (item 0: "
    "amplitude in dB, 1: range in m, 2: "
    "flags)\"}}}},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo "
    "amplitude of slice in dB\"}},\"required\":[\"amplitude\",\"table\"],\"type\":\"o"
    "bject\",\"description\":\"Window echo correction parameter slice\"}},\"ampli"
    "tude\":{\"properties\":{\"minimum\":{\"minimum\":0.0,\"type\":\"number\",\"descrip"
    "tion\":\"Minimum amplitude in "
    "dB\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "amplitude entries\"},\"maximum\":{\"minimum\":0.0,\"type\":\"number\",\"descript"
    "ion\":\"Maximum amplitude in dB\"}},\"required\":[\"minimum\",\"maximum\",\"entr"
    "ies\"],\"type\":\"object\",\"description\":\"Amplitude axis of correction tabl"
    "e\"},\"range\":{\"properties\":{\"minimum\":{\"minimum\":-2.0,\"maximum\":2.0,\"ty"
    "pe\":\"number\",\"description\":\"Minimum range in "
    "m\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "range entries\"},\"maximum\":{\"minimum\":-2.0,\"maximum\":2.0,\"type\":\"number"
    "\",\"description\":\"Maximum range in m\"}},\"required\":[\"minimum\",\"maximum\""
    ",\"entries\"],\"type\":\"object\",\"description\":\"Range axis of correction ta"
    "ble\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"description\":\"Correcti"
    "on parameters for window glass echoes\",\"title\":\"Window Echo "
    "Correction\"}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"amplitude\":{\"minimum\":2,\"entries\":128,\"maximum\":20},\"range\":{\"minim"
    "um\":-1.5060822940732335,\"entries\":128,\"maximum\":1.5060822940732335}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
