/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author RIEGL LMS GmbH, Austria
 * \brief  Description of RIEGL RDB 2 database file contents
 *
 *  NOTE: All information in this file is preliminary, since the
 *        definition of the database schemas is not yet complete.
 *
 *******************************************************************************
 */

#ifndef RDB_6DC7FF98_C890_4397_90B3_45A2547A201F
#define RDB_6DC7FF98_C890_4397_90B3_45A2547A201F

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// File schema version
const std::string RDB_SCHEMA_VERSION = "f274d50d";
const std::string RDB_SCHEMA_DATE = "2023-11-30";

// Schema for ".avg.fwa" files
const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.amplitude\",\"riegl.gain"
    "\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset\",\"riegl.wfm_sbl_id\",\"r"
    "iegl.deviation?\",\"riegl.pulse_width?\"],\"identifier\":\"avg.fwa\",\"extensi"
    "on\":\"avg.fwa\"}"
);

// Schema for ".avg.sbx" files
const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.wfm_sbl_channel\",\"rieg"
    "l.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl.wfm_sbl_time_offset\",\"r"
    "iegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"identifier\":\"avg.sbx\",\"ext"
    "ension\":\"avg.sbx\"}"
);

// Schema for ".avg.sidx" files
const std::string RDB_SCHEMA_RIEGL_AVG_SIDX(
    "{\"metadata\":[\"riegl.shot_info\",\"riegl.waveform_info\",\"riegl.echo_info?"
    "\",\"riegl.waveform_averaging_settings\"],\"attributes\":[\"riegl.id\",\"riegl"
    ".shot_timestamp_hr*\",\"riegl.wfm_sbl_first\",\"riegl.wfm_sbl_count\",\"rieg"
    "l.echo_first?\",\"riegl.echo_count?\"],\"identifier\":\"avg.sidx\",\"extension"
    "\":\"avg.sidx\"}"
);

// Schema for ".avg.sp{C}" files
const std::string RDB_SCHEMA_RIEGL_AVG_SPC(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.wfm_sample_value\"],\"id"
    "entifier\":\"avg.sp{C}\",\"extension\":\"avg.sp{C}\"}"
);

// Schema for ".cpx" files
const std::string RDB_SCHEMA_RIEGL_CPX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.control_object_catalog\",\"riegl.ite"
    "m_names\",\"riegl.imported_files\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\""
    ",\"riegl.xyz_accuracies\",\"riegl.control_object_type\",\"riegl.zenith_vect"
    "or\",\"riegl.used_for_adjustment\",\"riegl.acquisition_date?\",\"riegl.cp_su"
    "rface_inclination_angle\",\"riegl.cp_surface_inclination_tolerance_angle"
    "\",\"riegl.cp_search_radius?\",\"riegl.cp_maximum_distance?\",\"riegl.import"
    "_line_number\"],\"identifier\":\"cpx\",\"extension\":\"cpx\"}"
);

// Schema for ".doix" files
const std::string RDB_SCHEMA_RIEGL_DOIX(
    "{\"metadata\":[],\"attributes\":[\"riegl.id\",\"riegl.shot_origin\",\"riegl.sho"
    "t_direction*\",\"riegl.scan_line_index\",\"riegl.shot_index_line\"],\"identi"
    "fier\":\"doix\",\"extension\":\"doix\"}"
);

// Schema for ".eifx" files
const std::string RDB_SCHEMA_RIEGL_EIFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.ttip_configurati"
    "on?\"],\"attributes\":[\"riegl.id\",\"riegl.event_timestamp*\",\"riegl.event_i"
    "ndex?\",\"riegl.event_pulse_width?\",\"riegl.event_fake_pulse?\",\"riegl.raw"
    "_line_angle?\",\"riegl.raw_frame_angle?\"],\"identifier\":\"eifx\",\"extension"
    "\":\"eifx\"}"
);

// Schema for ".epfx" files
const std::string RDB_SCHEMA_RIEGL_EPFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\",\"riegl."
    "ttip_configuration?\"],\"attributes\":[\"riegl.id\",\"riegl.event_timestamp*"
    "\",\"riegl.event_index?\",\"riegl.event_pulse_width?\",\"riegl.event_fake_pu"
    "lse?\",\"riegl.raw_line_angle?\",\"riegl.raw_frame_angle?\",\"riegl.xyz\",\"ri"
    "egl.model_cs_axis_x\",\"riegl.model_cs_axis_y\",\"riegl.model_cs_axis_z\"],"
    "\"identifier\":\"epfx\",\"extension\":\"epfx\"}"
);

// Schema for ".fwa" files
const std::string RDB_SCHEMA_RIEGL_FWA(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.amplitude\",\"riegl.gain"
    "\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset\",\"riegl.wfm_sbl_id\",\"r"
    "iegl.deviation?\",\"riegl.pulse_width?\",\"riegl.extinction?\",\"riegl.svb_a"
    "mplitude_volumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?\",\"riegl."
    "svb_path_length?\"],\"identifier\":\"fwa\",\"extension\":\"fwa\"}"
);

// Schema for ".llhx" files
const std::string RDB_SCHEMA_RIEGL_LLHX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"attri"
    "butes\":[\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\","
    "\"riegl.pof_timestamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_"
    "east\",\"riegl.pof_accuracy_down\",\"riegl.pof_pdop\",\"riegl.pof_hdop\",\"rie"
    "gl.pof_vdop\",\"riegl.pof_age_of_corrections\",\"riegl.pof_baseline_length"
    "\",\"riegl.pof_solution_gnss\",\"riegl.pof_satellites_gnss\",\"riegl.id\"],\"i"
    "dentifier\":\"llhx\",\"extension\":\"llhx\"}"
);

// Schema for ".mpx" files
const std::string RDB_SCHEMA_RIEGL_MPX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.pixel_info\",\"riegl.time_base?\"],\"a"
    "ttributes\":[\"riegl.id\",\"riegl.xy_map*\",\"riegl.amplitude\",\"riegl.reflec"
    "tance\",\"riegl.deviation\",\"riegl.timestamp_min?\",\"riegl.timestamp_max?\""
    ",\"riegl.point_count\",\"riegl.point_count_grid_cell\",\"riegl.pixel_linear"
    "_sums?\",\"riegl.pixel_square_sums?\",\"riegl.height_min\",\"riegl.height_ma"
    "x\",\"riegl.height_mean\",\"riegl.height_center\",\"riegl.surface_normal\",\"r"
    "iegl.pca_thickness\",\"riegl.std_dev\",\"riegl.voxel_count\"],\"identifier\":"
    "\"mpx\",\"extension\":\"mpx\"}"
);

// Schema for ".mtch" files
const std::string RDB_SCHEMA_RIEGL_MTCH(
    "{\"metadata\":[\"riegl.plane_patch_matching\"],\"attributes\":[\"riegl.xyz*\","
    "\"riegl.plane_references\",\"riegl.plane_patch_distance\",\"riegl.plane_pat"
    "ch_lateral_distance\",\"riegl.plane_patch_link_vector\",\"riegl.id\"],\"iden"
    "tifier\":\"mtch\",\"extension\":\"mtch\"}"
);

// Schema for ".mvx" files
const std::string RDB_SCHEMA_RIEGL_MVX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.time_base?\",\"riegl.voxel_info\"],\"a"
    "ttributes\":[\"riegl.id\",\"riegl.xyz_map*\",\"riegl.amplitude\",\"riegl.refle"
    "ctance\",\"riegl.deviation\",\"riegl.timestamp_min?\",\"riegl.timestamp_max?"
    "\",\"riegl.point_count\",\"riegl.shape_id\",\"riegl.covariances?\",\"riegl.pca"
    "_axis_min\",\"riegl.pca_axis_max\",\"riegl.pca_extents\",\"riegl.std_dev\",\"r"
    "iegl.voxel_collapsed\"],\"identifier\":\"mvx\",\"extension\":\"mvx\"}"
);

// Schema for ".obsx" files
const std::string RDB_SCHEMA_RIEGL_OBSX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.plane_slope_class_info?\",\"riegl.po"
    "intcloud_info\",\"riegl.sda1_source_files\"],\"attributes\":[\"riegl.xyz\",\"r"
    "iegl.surface_normal\",\"riegl.plane_slope_class?\",\"riegl.id*\",\"riegl.sda"
    "1_plane_patch_one\",\"riegl.sda1_plane_patch_two\",\"riegl.sda1_source_fil"
    "e_one\",\"riegl.sda1_source_file_two\"],\"identifier\":\"obsx\",\"extension\":\""
    "obsx\"}"
);

// Schema for ".opefx" files
const std::string RDB_SCHEMA_RIEGL_OPEFX(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"attribute"
    "s\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies?\",\"riegl.surface_nor"
    "mal\",\"riegl.plane_up\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.plane"
    "_width\",\"riegl.plane_height\",\"riegl.plane_confidence_normal\",\"riegl.mo"
    "del_fit_quality?\",\"riegl.used_for_adjustment\",\"riegl.xyz_socs\",\"riegl."
    "timestamp\",\"riegl.mirror_facet\",\"riegl.platform_rpy_ROCS_NED\",\"riegl.p"
    "latform_drpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU\",\"riegl.platform_d"
    "xyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw_range\",\"riegl.raw_fr"
    "ame_angle\",\"riegl.raw_line_angle\",\"riegl.reference_object_id\"],\"identi"
    "fier\":\"opefx\",\"extension\":\"opefx\"}"
);

// Schema for ".opp" files
const std::string RDB_SCHEMA_RIEGL_OPP(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"attribute"
    "s\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies?\",\"riegl.surface_nor"
    "mal\",\"riegl.plane_up\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.plane"
    "_width\",\"riegl.plane_height\",\"riegl.plane_confidence_normal\",\"riegl.mo"
    "del_fit_quality?\",\"riegl.used_for_adjustment\",\"riegl.xyz_socs\",\"riegl."
    "timestamp\",\"riegl.mirror_facet\",\"riegl.platform_rpy_ROCS_NED\",\"riegl.p"
    "latform_drpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU\",\"riegl.platform_d"
    "xyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw_range\",\"riegl.raw_fr"
    "ame_angle\",\"riegl.raw_line_angle\",\"riegl.reference_object_id\"],\"identi"
    "fier\":\"opp\",\"extension\":\"opp\"}"
);

// Schema for ".opx" files
const std::string RDB_SCHEMA_RIEGL_OPX(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.control_object_catalog\",\"riegl.item_names\",\"riegl.control_obj"
    "ect_reference_file\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.cont"
    "rol_object_type\",\"riegl.model_cs_axis_x?\",\"riegl.model_cs_axis_y?\",\"ri"
    "egl.model_cs_axis_z?\",\"riegl.model_fit_quality?\",\"riegl.obs_confidence"
    "_xy?\",\"riegl.obs_confidence_z?\",\"riegl.obs_signal_confidence_rot?\",\"ri"
    "egl.obs_confidence_range?\",\"riegl.obs_confidence_theta?\",\"riegl.obs_co"
    "nfidence_phi?\",\"riegl.point_count?\",\"riegl.used_for_adjustment\",\"riegl"
    ".xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\"riegl.platform_rpy_"
    "ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU\""
    ",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw_ra"
    "nge\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\",\"riegl.reference_o"
    "bject_id\"],\"identifier\":\"opx\",\"extension\":\"opx\"}"
);

// Schema for ".owp" files
const std::string RDB_SCHEMA_RIEGL_OWP(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.raw_range\",\"riegl.ampl"
    "itude\",\"riegl.deviation\",\"riegl.gain\"],\"identifier\":\"owp\",\"extension\":"
    "\"owp\"}"
);

// Schema for ".pefx" files
const std::string RDB_SCHEMA_RIEGL_PEFX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.vertex_info\",\"riegl.item_names\",\"r"
    "iegl.imported_files\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz"
    "_accuracies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.std_dev\","
    "\"riegl.plane_confidence_normal\",\"riegl.plane_width\",\"riegl.plane_heigh"
    "t\",\"riegl.vertex_first\",\"riegl.vertex_count\",\"riegl.used_for_adjustmen"
    "t\",\"riegl.acquisition_date?\",\"riegl.import_line_number\",\"riegl.import_"
    "line_count\"],\"identifier\":\"pefx\",\"extension\":\"pefx\"}"
);

// Schema for ".pofx" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.trajectory_info\""
    "],\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_latitude\""
    ",\"riegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof_roll\",\"riegl.pof_"
    "pitch\",\"riegl.pof_yaw\",\"riegl.pof_path_length?\"],\"identifier\":\"project"
    ".pofx\",\"extension\":\"pofx\"}"
);

// Schema for ".pofx" files
const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.geo_tag\",\"riegl."
    "trajectory_info\"],\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"rie"
    "gl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof_r"
    "oll\",\"riegl.pof_pitch\",\"riegl.pof_yaw\",\"riegl.pof_path_length?\",\"riegl"
    ".pof_xyz\",\"riegl.pof_roll_ned\",\"riegl.pof_pitch_ned\",\"riegl.pof_yaw_ne"
    "d\"],\"identifier\":\"scan.pofx\",\"extension\":\"pofx\"}"
);

// Schema for ".poqx" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"attributes\":["
    "\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_accuracy_north\",\"riegl.po"
    "f_accuracy_east\",\"riegl.pof_accuracy_down\",\"riegl.pof_accuracy_roll\",\""
    "riegl.pof_accuracy_pitch\",\"riegl.pof_accuracy_yaw\",\"riegl.pof_path_len"
    "gth?\",\"riegl.pof_pdop\",\"riegl.pof_satellites_gnss?\",\"riegl.pof_satelli"
    "tes_gps?\",\"riegl.pof_satellites_glonass?\",\"riegl.pof_satellites_beidou"
    "?\",\"riegl.pof_satellites_galileo?\",\"riegl.pof_satellites_qzss?\"],\"iden"
    "tifier\":\"project.poqx\",\"extension\":\"poqx\"}"
);

// Schema for ".poqx" files
const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"attributes\":["
    "\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_accuracy_north\",\"riegl.po"
    "f_accuracy_east\",\"riegl.pof_accuracy_down\",\"riegl.pof_accuracy_roll\",\""
    "riegl.pof_accuracy_pitch\",\"riegl.pof_accuracy_yaw\",\"riegl.pof_path_len"
    "gth?\",\"riegl.pof_pdop\",\"riegl.pof_satellites_gnss?\",\"riegl.pof_satelli"
    "tes_gps?\",\"riegl.pof_satellites_glonass?\",\"riegl.pof_satellites_beidou"
    "?\",\"riegl.pof_satellites_galileo?\",\"riegl.pof_satellites_qzss?\"],\"iden"
    "tifier\":\"scan.poqx\",\"extension\":\"poqx\"}"
);

// Schema for ".ppx" files
const std::string RDB_SCHEMA_RIEGL_PPX(
    "{\"metadata\":[\"riegl.device\",\"riegl.time_base\"],\"attributes\":[\"riegl.id"
    "\",\"riegl.pps_timestamp_intern*\",\"riegl.pps_timestamp_extern\"],\"identif"
    "ier\":\"ppx\",\"extension\":\"ppx\"}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"attributes\":[\"riegl."
    "xyz*\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"ri"
    "egl.point_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_heig"
    "ht\",\"riegl.plane_count\",\"riegl.covariances\",\"riegl.id\"],\"identifier\":\""
    "project.ptch\",\"extension\":\"ptch\"}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.plane_patch_statistics?\",\"riegl.plane_slope_class_info?\"],\"at"
    "tributes\":[\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl.direction?\",\"riegl.dir"
    "ection_medium?\",\"riegl.direction_coarse?\",\"riegl.surface_normal\",\"rieg"
    "l.plane_up\",\"riegl.timestamp\",\"riegl.reflectance?\",\"riegl.point_count\""
    ",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane"
    "_count\",\"riegl.mirror_facet\",\"riegl.covariances\",\"riegl.id\",\"riegl.pla"
    "ne_slope_class?\",\"riegl.plane_occupancy\",\"riegl.plane_confidence_norma"
    "l\",\"riegl.plane_cog_link\",\"riegl.match_count\",\"riegl.platform_rpy_ROCS"
    "_NED\",\"riegl.platform_xyz_ROCS_ENU\",\"riegl.platform_drpy_ROCS_NED\",\"ri"
    "egl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw_range\""
    ",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\"],\"identifier\":\"scan.pt"
    "ch\",\"extension\":\"ptch\"}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"attributes\":[\"riegl."
    "xyz*\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"ri"
    "egl.point_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_heig"
    "ht\",\"riegl.plane_count\",\"riegl.covariances\",\"riegl.id\"],\"identifier\":\""
    "scanpos.ptch\",\"extension\":\"ptch\"}"
);

// Schema for ".rdbx" files
const std::string RDB_SCHEMA_RIEGL_RDBX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
    "orrection?\"],\"attributes\":[\"riegl.id\",\"riegl.timestamp\",\"riegl.xyz*\",\""
    "riegl.xyz_socs\",\"riegl.direction_medium?\",\"riegl.direction?\",\"riegl.am"
    "plitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\"riegl.pulse_width?\","
    "\"riegl.target_index\",\"riegl.target_count\",\"riegl.mirror_facet?\",\"riegl"
    ".scan_segment?\",\"riegl.mta_uncertain_point?\",\"riegl.mta_zone?\",\"riegl."
    "window_echo_impact_corrected?\",\"riegl.dyntrig_uncertain_point?\",\"riegl"
    ".rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\",\"riegl.end_of_scan_"
    "line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"riegl.waveform_availabl"
    "e?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offset?\",\"riegl.scan_angl"
    "e\",\"riegl.scan_direction\",\"riegl.source_index?\",\"riegl.scan_line_index"
    "?\",\"riegl.shot_index_line?\",\"riegl.hydro_intersection_point?\",\"riegl.h"
    "ydro_intersection_normal?\",\"riegl.extinction?\",\"riegl.svb_amplitude_vo"
    "lumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?\",\"riegl.svb_path_le"
    "ngth?\"],\"identifier\":\"rdbx\",\"extension\":\"rdbx\"}"
);

// Schema for ".rmvx" files
const std::string RDB_SCHEMA_RIEGL_RMVX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.voxel_info\",\"riegl.time_base?\"],\"a"
    "ttributes\":[\"riegl.id\",\"riegl.voxel_index*\",\"riegl.amplitude\",\"riegl.r"
    "eflectance\",\"riegl.deviation\",\"riegl.direction_medium\",\"riegl.point_co"
    "unt\",\"riegl.voxel_linear_sums\",\"riegl.voxel_square_sums\",\"riegl.timest"
    "amp_min?\",\"riegl.timestamp_max?\"],\"identifier\":\"rmvx\",\"extension\":\"rmv"
    "x\"}"
);

// Schema for ".s10x" files
const std::string RDB_SCHEMA_RIEGL_S10X(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.device?\",\"riegl.pose_sensors\"],\""
    "attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl.frame_angle_coarse\","
    "\"riegl.gyroscope_raw\",\"riegl.accelerometer_raw\",\"riegl.magnetic_field_"
    "sensor_raw\",\"riegl.gyroscope\",\"riegl.accelerometer\",\"riegl.magnetic_fi"
    "eld_sensor\",\"riegl.barometric_height_amsl\",\"riegl.temperature\",\"riegl."
    "line_scan_active\",\"riegl.frame_scan_active\",\"riegl.data_acquisition_ac"
    "tive\"],\"identifier\":\"s10x\",\"extension\":\"s10x\"}"
);

// Schema for ".sbx" files
const std::string RDB_SCHEMA_RIEGL_SBX(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.wfm_sbl_channel\",\"rieg"
    "l.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl.wfm_sbl_time_offset\",\"r"
    "iegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"identifier\":\"sbx\",\"extensi"
    "on\":\"sbx\"}"
);

// Schema for ".sdcx" files
const std::string RDB_SCHEMA_RIEGL_SDCX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.mta_settings?\",\"riegl.near_range_correction"
    "?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch"
    "_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\","
    "\"riegl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectan"
    "ce_calculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\","
    "\"riegl.time_base\",\"riegl.window_analysis?\",\"riegl.window_echo_correcti"
    "on?\"],\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl.xyz\",\"riegl.a"
    "mplitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\"riegl.pulse_width?\""
    ",\"riegl.target_index\",\"riegl.target_count\",\"riegl.mirror_facet?\",\"rieg"
    "l.scan_segment?\",\"riegl.mta_uncertain_point?\",\"riegl.mta_zone?\",\"riegl"
    ".window_echo_impact_corrected?\",\"riegl.dyntrig_uncertain_point?\",\"rieg"
    "l.class?\",\"riegl.start_of_scan_line?\",\"riegl.end_of_scan_line?\",\"riegl"
    ".source_indicator?\",\"riegl.fwa?\",\"riegl.waveform_available?\",\"riegl.wf"
    "m_sbl_id?\",\"riegl.wfm_echo_time_offset?\",\"riegl.extinction?\",\"riegl.sv"
    "b_amplitude_volumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?\",\"rie"
    "gl.svb_path_length?\"],\"identifier\":\"sdcx\",\"extension\":\"sdcx\"}"
);

// Schema for ".sidx" files
const std::string RDB_SCHEMA_RIEGL_SIDX(
    "{\"metadata\":[\"riegl.shot_info\",\"riegl.echo_info\"],\"attributes\":[\"riegl"
    ".id\",\"riegl.shot_timestamp_hr*\",\"riegl.echo_first\",\"riegl.echo_count\"]"
    ",\"identifier\":\"sidx\",\"extension\":\"sidx\"}"
);

// Schema for ".sodx" files
const std::string RDB_SCHEMA_RIEGL_SODX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.device\",\"riegl.device_geometry\""
    ",\"riegl.device_output_limits\",\"riegl.beam_geometry\",\"riegl.near_range_"
    "correction?\",\"riegl.window_echo_correction?\",\"riegl.receiver_internals"
    "?\",\"riegl.gaussian_decomposition?\",\"riegl.exponential_decomposition?\","
    "\"riegl.mta_settings?\",\"riegl.pulse_position_modulation?\",\"riegl.notch_"
    "filter?\",\"riegl.reflectance_calculation?\",\"riegl.scan_pattern\",\"riegl."
    "time_base\",\"riegl.waveform_info?\",\"riegl.echo_info?\"],\"attributes\":[\"r"
    "iegl.id\",\"riegl.shot_timestamp_hr*\",\"riegl.mirror_facet\",\"riegl.scan_s"
    "egment\",\"riegl.start_of_scan_line\",\"riegl.line_angle_coarse\",\"riegl.sh"
    "ot_origin\",\"riegl.shot_biaxial_shift?\",\"riegl.shot_direction\",\"riegl.s"
    "hot_direction_levelled?\",\"riegl.wfm_sbl_first?\",\"riegl.wfm_sbl_count?\""
    ",\"riegl.echo_first?\",\"riegl.echo_count?\"],\"identifier\":\"sodx\",\"extensi"
    "on\":\"sodx\"}"
);

// Schema for ".sp{C}" files
const std::string RDB_SCHEMA_RIEGL_SPC(
    "{\"metadata\":[],\"attributes\":[\"riegl.id*\",\"riegl.wfm_sample_value\"],\"id"
    "entifier\":\"sp{C}\",\"extension\":\"sp{C}\"}"
);

// Schema for ".vtx" files
const std::string RDB_SCHEMA_RIEGL_VTX(
    "{\"metadata\":[\"riegl.geo_tag\"],\"attributes\":[\"riegl.id*\",\"riegl.xyz\",\"r"
    "iegl.xyz_accuracies?\"],\"identifier\":\"vtx\",\"extension\":\"vtx\"}"
);

// Schema for ".vxls" files
const std::string RDB_SCHEMA_RIEGL_VXLS(
    "{\"metadata\":[\"riegl.voxel_info\",\"riegl.geo_tag?\"],\"attributes\":[\"riegl"
    ".id\",\"riegl.xyz*\",\"riegl.covariances\",\"riegl.pca_axis_max\",\"riegl.pca_"
    "axis_min\",\"riegl.pca_extents\",\"riegl.point_count\",\"riegl.reflectance\","
    "\"riegl.shape_id\",\"riegl.voxel_collapsed\",\"riegl.std_dev?\"],\"identifier"
    "\":\"vxls\",\"extension\":\"vxls\"}"
);

// Schema for ".wdcx" files
const std::string RDB_SCHEMA_RIEGL_WDCX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
    "orrection?\"],\"attributes\":[\"riegl.id\",\"riegl.timestamp\",\"riegl.xyz*\",\""
    "riegl.xyz_socs\",\"riegl.direction_medium?\",\"riegl.direction?\",\"riegl.am"
    "plitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\"riegl.pulse_width?\","
    "\"riegl.target_index\",\"riegl.target_count\",\"riegl.mirror_facet?\",\"riegl"
    ".scan_segment?\",\"riegl.mta_uncertain_point?\",\"riegl.mta_zone?\",\"riegl."
    "window_echo_impact_corrected?\",\"riegl.dyntrig_uncertain_point?\",\"riegl"
    ".rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\",\"riegl.end_of_scan_"
    "line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"riegl.waveform_availabl"
    "e?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offset?\",\"riegl.scan_angl"
    "e\",\"riegl.scan_direction\",\"riegl.source_index?\",\"riegl.scan_line_index"
    "?\",\"riegl.shot_index_line?\",\"riegl.hydro_intersection_point?\",\"riegl.h"
    "ydro_intersection_normal?\",\"riegl.extinction?\",\"riegl.svb_amplitude_vo"
    "lumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?\",\"riegl.svb_path_le"
    "ngth?\"],\"identifier\":\"wdcx\",\"extension\":\"wdcx\"}"
);

// Schema for ".wex" files
const std::string RDB_SCHEMA_RIEGL_WEX(
    "{\"metadata\":[\"riegl.device\",\"riegl.notch_filter\",\"riegl.window_analysi"
    "s\"],\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl.wex_filter_vali"
    "d\",\"riegl.wex_point_count\",\"riegl.wex_amplitude\",\"riegl.wex_amplitude_"
    "std_dev\",\"riegl.wex_amplitude_min\",\"riegl.wex_amplitude_max\",\"riegl.we"
    "x_amplitude_offset\",\"riegl.wex_deviation\",\"riegl.wex_deviation_std_dev"
    "\",\"riegl.wex_deviation_min\",\"riegl.wex_deviation_max\",\"riegl.wex_range"
    "\",\"riegl.wex_range_std_dev\",\"riegl.wex_range_min\",\"riegl.wex_range_max"
    "\",\"riegl.wex_filter_range_min\",\"riegl.wex_filter_range_max\",\"riegl.wex"
    "_filter_amplitude_max\"],\"identifier\":\"wex\",\"extension\":\"wex\"}"
);

// Table of all RDB file schema strings
const std::string RDB_SCHEMA_ARRAY[] = {
    RDB_SCHEMA_RIEGL_AVG_FWA,
    RDB_SCHEMA_RIEGL_AVG_SBX,
    RDB_SCHEMA_RIEGL_AVG_SIDX,
    RDB_SCHEMA_RIEGL_AVG_SPC,
    RDB_SCHEMA_RIEGL_CPX,
    RDB_SCHEMA_RIEGL_DOIX,
    RDB_SCHEMA_RIEGL_EIFX,
    RDB_SCHEMA_RIEGL_EPFX,
    RDB_SCHEMA_RIEGL_FWA,
    RDB_SCHEMA_RIEGL_LLHX,
    RDB_SCHEMA_RIEGL_MPX,
    RDB_SCHEMA_RIEGL_MTCH,
    RDB_SCHEMA_RIEGL_MVX,
    RDB_SCHEMA_RIEGL_OBSX,
    RDB_SCHEMA_RIEGL_OPEFX,
    RDB_SCHEMA_RIEGL_OPP,
    RDB_SCHEMA_RIEGL_OPX,
    RDB_SCHEMA_RIEGL_OWP,
    RDB_SCHEMA_RIEGL_PEFX,
    RDB_SCHEMA_RIEGL_PROJECT_POFX,
    RDB_SCHEMA_RIEGL_SCAN_POFX,
    RDB_SCHEMA_RIEGL_PROJECT_POQX,
    RDB_SCHEMA_RIEGL_SCAN_POQX,
    RDB_SCHEMA_RIEGL_PPX,
    RDB_SCHEMA_RIEGL_PROJECT_PTCH,
    RDB_SCHEMA_RIEGL_SCAN_PTCH,
    RDB_SCHEMA_RIEGL_SCANPOS_PTCH,
    RDB_SCHEMA_RIEGL_RDBX,
    RDB_SCHEMA_RIEGL_RMVX,
    RDB_SCHEMA_RIEGL_S10X,
    RDB_SCHEMA_RIEGL_SBX,
    RDB_SCHEMA_RIEGL_SDCX,
    RDB_SCHEMA_RIEGL_SIDX,
    RDB_SCHEMA_RIEGL_SODX,
    RDB_SCHEMA_RIEGL_SPC,
    RDB_SCHEMA_RIEGL_VTX,
    RDB_SCHEMA_RIEGL_VXLS,
    RDB_SCHEMA_RIEGL_WDCX,
    RDB_SCHEMA_RIEGL_WEX
};
const std::size_t RDB_SCHEMA_COUNT(
    sizeof(RDB_SCHEMA_ARRAY) / sizeof(RDB_SCHEMA_ARRAY[0])
);
const std::vector<std::string> RDB_SCHEMA_VECTOR(
    RDB_SCHEMA_ARRAY, RDB_SCHEMA_ARRAY + RDB_SCHEMA_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_6DC7FF98_C890_4397_90B3_45A2547A201F
